Django Suit
===========

**Modern theme for Django admin interface**.

Django Suit is alternative theme/skin/extension for `Django <http://www.djangoproject.com>`_ administration interface.

Project home: http://djangosuit.com/


License
-------

Django Suit is licensed under `Creative Commons Attribution-NonCommercial 3.0 <http://creativecommons.org/licenses/by-nc/3.0/>`_ license.

Licence and pricing: http://djangosuit.com/pricing/


Support
-------

Support and documentation: http://djangosuit.com/support/


Changelog
---------

`See CHANGELOG.rst <CHANGELOG.rst>`_
